# Audio Visualization

Animated audio visualization clips rendered via Cairo.

## WaveformClip

::: pymotion.clip.audio_viz.WaveformClip

## SpectrumClip

::: pymotion.clip.audio_viz.SpectrumClip

## SpectrogramClip

::: pymotion.clip.audio_viz.SpectrogramClip

## AudioReactiveEffect

::: pymotion.clip.audio_viz.AudioReactiveEffect
